==> amarok-1.86.tar.bz2: amarok-1.86/src/playlist/RandomAlbumNavigator.h <==
/***************************************************************************
 * copyright   : (C) 2008 Nikolaj Hald Nielsen <nhnFreespirit@gmail.com>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy 
 * defined in Section 14 of version 3 of the license.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 
#ifndef RANDOMALBUMNAVIGATOR_H
#define RANDOMALBUMNAVIGATOR_H

#include "meta/Meta.h"
#include "playlist/PlaylistModel.h"
#include "playlist/PlaylistRowList.h"
#include "playlist/TrackNavigator.h"

namespace Playlist {
    class Model;

/**
Navigator for playing back albums in random order

	@author Nikolaj Hald Nielsen <nhnFreespirit@gmail.com>
*/
class RandomAlbumNavigator : public TrackNavigator
{
public:
    RandomAlbumNavigator( Model *m ) : TrackNavigator( m ) { generateAlbumHeaders(); }

    int nextRow();
    int lastRow();

    private:
        void generateAlbumHeaders();
        void generateUnplayedAlbums();
        RowList m_albumHeaders;
        RowList m_playedRows;
        RowList m_unplayedAlbums;
};

}

#endif

==> amarok-1.92.2.tar.bz2: amarok-1.92.2/src/playlist/RandomAlbumNavigator.h <==
/***************************************************************************
 * copyright   : (C) 2008 Nikolaj Hald Nielsen <nhnFreespirit@gmail.com>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy 
 * defined in Section 14 of version 3 of the license.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 
#ifndef RANDOMALBUMNAVIGATOR_H
#define RANDOMALBUMNAVIGATOR_H

#include "meta/Meta.h"
#include "playlist/PlaylistModel.h"
#include "playlist/PlaylistRowList.h"
#include "playlist/SimpleTrackNavigator.h"

namespace Playlist {
    class Model;

/**
Navigator for playing back albums in random order

	@author Nikolaj Hald Nielsen <nhnFreespirit@gmail.com>
*/
class RandomAlbumNavigator : public SimpleTrackNavigator
{
    public:
        RandomAlbumNavigator( Model *m ) : SimpleTrackNavigator( m ) { generateAlbumHeaders(); }

    private:
        int nextRow();
        int lastRow();

        void generateAlbumHeaders();
        void generateUnplayedAlbums();
        RowList m_albumHeaders;
        RowList m_playedRows;
        RowList m_unplayedAlbums;
};

}

#endif
